==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/genericinterface/kmfgenericinterfacenat.h <==
//
//
// C++ Interface: $MODULE$
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@gmail.com>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFGENERICINTERFACENAT_H
#define KMFGENERICINTERFACENAT_H

#include <kmyfirewallgenericinterfacenatwidget.h>

/**
@author Christian Hubinger
*/

class KMFGenericDoc;

class KMFGenericInterfaceNat : public KMyFirewallGenericInterfaceNATWidget {
	Q_OBJECT
public:
	KMFGenericInterfaceNat( QWidget *parent = 0, const char *name = 0, WFlags f = 0 );

	~KMFGenericInterfaceNat();
signals:


public slots:
	void slotUpdateView();

public:
	void loadDoc( KMFGenericDoc* );


private:
	KMFGenericDoc *m_doc;	

    private slots: void slotAddressChanged( const QString& );
    private slots: void slotMasqueradeEnabled( bool );
    private slots: void slotNatEnabled( bool );
    private slots: void slotExternalInterfaceChanged( const QString& );
};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/genericinterface/kmfgenericinterfacenat.h <==
//
//
// C++ Interface: $MODULE$
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFGENERICINTERFACENAT_H
#define KMFGENERICINTERFACENAT_H

#include <kmyfirewallgenericinterfacenatwidget.h>

// QT Includes
#include <qguardedptr.h>

/**
@author Christian Hubinger
*/

namespace KMF {
class KMFNetwork;
class KMFGenericDoc;
class NetfilterObject;

class KMFGenericInterfaceNat : public KMyFirewallGenericInterfaceNATWidget {
	Q_OBJECT
public:
	KMFGenericInterfaceNat( QWidget *parent = 0, const char *name = 0, WFlags f = 0 );

	~KMFGenericInterfaceNat();
signals:


public slots:
	void slotUpdateView();
	void slotUpdateView( NetfilterObject* );

public:
	void loadDoc( KMFNetwork* );


private:
	QGuardedPtr<KMFNetwork> m_doc;	

    private slots: void slotAddressChanged( const QString& );
    private slots: void slotMasqueradeEnabled( bool );
    private slots: void slotNatEnabled( bool );
    private slots: void slotExternalInterfaceChanged( const QString& );
};
}
#endif
